# contour-ai-sdk

 The Contour AI SDK™ has been designed to be the industry’s most intuitive, and protected, experience for mobile image capture - capturing documents of various kinds via an iOS™ or Android™ mobile device. At the same time, it has been designed to enable the clear, accurate, and complete processing of these documents with limited, if any, human intervention, all while improving your efficiencies and reducing costs.

  ## Installation

 ```sh
npm install  contour-ai-sdk
```

  ## Usage

 ```js
import { startContourSDK } from  'contour-ai-sdk';

startContourSDK('<Check_Face>'', '<CLIENT_ID>', <Capturing_Type>, <Multiple_Capturing>, updateState);

 const updateState = (e: any) => {
	 const frontUri = e.frontUri;
	 const rearUri = e.rearUri;
	 if (frontUri && rearUri) {
	 //Your code goes here.
	 }
};
```
Value of  **Check_Face** :- 
```
front - For capturing both side of check.
frontFaceOnly - For capturing front side of check.
back - For capturing rear side of check.
```

Value of  **Capturing_Type** :- 
```
both - Getting access to capture for Auto and Manual .
auto - Getting access to capture for Auto only.
manual - Getting access to capture for manual only.
```

Value of  **Multiple_Capturing** :- 
```
true - Allows to capture multiple sets of check without closing the plugin .
false - Capture only single set of check.
```
```js

```

## iOS
These are the changes which need to be done for adding **UINavigationController** to open **ContourAI-SDK** 
```objectivec
#import <React/RCTBundleURLProvider.h>
#import <React/RCTRootView.h>
#import <ContoursAI_SDK/ContoursAI_SDK-Swift.h>
@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
// You can add your custom initial props in the dictionary below.
// They will be passed down to the ViewController used by React Native.

self.initialProps = @{};
RCTBridge *bridge = [[RCTBridge alloc] initWithDelegate:self launchOptions:launchOptions];
RCTRootView *rootView = [[RCTRootView alloc] initWithBridge:bridge
moduleName:@"<Your ModuleName>"
initialProperties:nil];

self.window = [[UIWindow alloc] initWithFrame:[UIScreen mainScreen].bounds];
UIViewController *rootViewController = [UIViewController new];
UINavigationController *navController = [[UINavigationController alloc]initWithRootViewController:rootViewController];

rootViewController.view = rootView ;
self.window.rootViewController = navController;
[self.window makeKeyAndVisible];
return  YES;
}

-(NSUInteger)application:(UIApplication *)application supportedInterfaceOrientationsForWindow:(UIWindow *)window
{
	  if ([ContoursAIFramework shared].isLandscape ) {
	  return UIInterfaceOrientationMaskLandscapeRight;
  } else {
	  return UIInterfaceOrientationMaskPortrait;
  }// you can change orientation for specific type . for ex landscape left
}
```

## Android
These are the changes which need to be done for to open **ContourAI-SDK** for Android.
Update android/app/build.gradle file. Add packagingOptions inside android{} block and contour dependency under dependencies block.
```
android {
    ndkVersion rootProject.ext.ndkVersion

    compileSdkVersion rootProject.ext.compileSdkVersion

    packagingOptions {
        pickFirst '/lib/armeabi-v7a/libopencv_java4.so'
        pickFirst '/lib/arm64-v8a/libopencv_java4.so'
        pickFirst '/lib/x86/libopencv_java4.so'
        pickFirst '/lib/x86_64/libopencv_java4.so'
    }
	dependencies {
		implementation 'com.github.Contour-Document-Imaging:contours-ai-android-sdk:latest_sdk_version'
	}
}
```
Update AndroidMenifest.xml like below if you are facing error to replace tools:replace="android:allowBackup"
```
<manifest xmlns:android="http://schemas.android.com/apk/res/android"
    xmlns:tools="http://schemas.android.com/tools">
	<application
		android:usesCleartextTraffic="true"
		tools:replace="android:allowBackup">
	</application>
```
Add contoursAI.license file under android/app/src/main/assets folder.
## License
 **Proprietary License**
The Contour AI SDK™ (the “SDK”) is, except as otherwise expressly stated, proprietary software owned by Contour Document Imaging, LLC (“CDI”) and may only be accessed and/or used pursuant to the terms of a License issued by CDI (“the License”).

By you accessing this SDK, which includes any related documentation, sample apps, and libraries, you acknowledge that either (i) you currently are a client of Urban FT Client Solutions, LLC (“Urban FT”) and you have a license granted to you by CDI which governs access to and use of the SDK (in which case, the terms and conditions of that license govern your use of the SDK) or (ii) you agree to the following terms and conditions:

You will use the SDK solely to evaluate the SDK for the purpose of internal development of software and applications to the extent necessary for such applications to transfer data to Urban FT, X-35, or CDI. You have no right to receive any underlying software or a copy of the object code or source code to the SDK. You will not make copies of the SDK. You will not make the SDK available to any third party. CDI shall own all modifications, revisions, or derivative works of the code contained in its SDK.

Your right to use the SDK is conditional upon the following. You may not: (i) sell, rent, lease or otherwise distribute or share the SDK; (ii) disassemble, decompile, reverse engineer the SDK or output from the foregoing or otherwise attempt to derive the source code (or the underlying ideas, algorithms, structure or organization); (iii) provide access to the SDK to any third party; (iv) create any derivative works based upon the SDK; (v) access the SDK in order to build a competitive solution or gather competitive intelligence or to assist someone else to build a competitive solution or gather competitive intelligence; (vi) use the SDK in a way that violates any applicable law; (vii) interfere with or disrupt the integrity or performance of the SDK, or (viii) attempt to gain unauthorized access to the related systems or networks of Urban FT, X-35, and/or CDI.

CDI is giving permission to you to use the SDK solely in accordance with these terms and conditions. The SDK is not being sold. CDI and/or its licensors retain the exclusive ownership of all rights, title, and interest, including all intellectual property rights, in and to the SDK and associated documentation, including but not limited (i) any components, corrections, updates, upgrades, methodologies, derivative works, and associated documentation thereof and (ii) all trademarks, trade names, trade secrets, and other proprietary information of CDI related thereto. CDI also owns all suggestions, ideas, enhancement requests, or feedback related to the SDK.

All rights not expressly granted to you are reserved by CDI and its licensors, and you shall have no rights which arise by implication or estoppel.
  

---
 For Documentation [Click here](https://docs.fttoolbox.com/contoursai/)

Made with [create-react-native-library](https://github.com/callstack/react-native-builder-bob)